@@ -5,7 +5,7 @@
 
 from ._fmt import fmtbib, fmts
 from ._helpers import unicode_to_utf8tex as to_utf8tex
-from ._helpers import (normalize_space, last_first, in_virtual,
+from ._helpers import (normalize_space, last_first,
                        cutoff_tokens, parse_placeholders)
 from ._files import File, cwdfiles
 from ._rename import renfile, rencwdfiles
